@@ -71,7 +71,8 @@ L<Chj::IO::File>, L<Chj::xsysopen>, L<Chj::xopendir>
 
 =head1 NOTE
 
-This is alpha software! Read the package README.
+This is alpha software! Read the status section in the package README
+or on the L<website|http://functional-perl.org/>.
 
 =cut
 
