@@ -200,6 +200,24 @@ sub new {
     $self
 }
 
+my $maybe_setter= sub {
+    my ($method)=@_;
+    sub {
+        @_== 2 or die "wrong number of arguments";
+        my ($self, $v)= @_;
+        my $set_maybe_method= "set_maybe_${method}";
+        defined $v
+            or die "set_${method} does not accept undef, use $set_maybe_method instead";
+        $self->$set_maybe_method($v);
+    }
+};
+for my $method (qw(historypath settingspath prompt package keepResultIn
+                input output env_PATH)) {
+    no strict 'refs';
+    my $var= "set_$method";
+    *$var= &$maybe_setter($method);
+}
+
 sub use_lexical_persistence {
     my $self=shift;
     hash_xref(+{m=>1, M=>1, x=>0, X=>0}, $self->mode_lexical_persistence)
@@ -316,6 +334,7 @@ If a command line starts with a ':' or ',', then the remainder of the
 line is interpreted as follows:
 
   package \$package    use \$package as new compilation package
+  p \$package          shortcut for package
   DIGITS              shorthand for 'f n', see below
   -                   same as 'f n' where n is the current frameno - 1
   +                   same as 'f n' where n is the current frameno + 1
@@ -339,7 +358,7 @@ previously used mode (indicated on the left):
 $L 1  use scalar context
 $l l  use list context (default)
   formatter:
-$p p  print stringification
+$p P  print stringification
 $s s  show from FP::Show (experimental, does not show data sharing)
 $d d  Data::Dumper (default)
   viewer:
@@ -612,6 +631,16 @@ sub _completion_function {
                         }
                     }
                 };
+
+                # Force any potential promises, since we want to
+                # complete methods on the resulting value, OK? TODO
+                # once typing framework is ready (FP::Type): mark type
+                # in promise, thus no need to force it.  Have to catch
+                # (and ignore, OK?) exceptions.
+                eval {
+                    $val= force $val;
+                };
+
                 if (defined $val) {
                     #warn "got value from \$$varnam";
                     if ($r||=ref($val)) {
@@ -1023,9 +1052,10 @@ sub run {
                                                     $frameno + 1 : undef)
                                  },
                                  package=> $set_package,
+                                 p=> $set_package,
                                  1=> saving ($self, sub { $$self[Mode_context]="1" }),
                                  l=> saving ($self, sub { $$self[Mode_context]="l" }),
-                                 p=> saving ($self, sub { $$self[Mode_formatter]="p" }),
+                                 P=> saving ($self, sub { $$self[Mode_formatter]="p" }),
                                  s=> saving ($self, sub { $$self[Mode_formatter]="s" }),
                                  d=> saving ($self, sub { $$self[Mode_formatter]="d" }),
                                  V=> saving ($self, sub { $$self[Mode_viewer]="V" }),
