@@ -55,7 +55,7 @@ our %dependencies=
    ],
    'FunctionalPerl::Htmlgen::PathUtil'=> [
        'Function::Parameters',
-       'File::Spec'
+       'File::Spec',
    ],
    'FunctionalPerl::Htmlgen::PathTranslate'=> [
        'Function::Parameters',
@@ -64,7 +64,7 @@ our %dependencies=
    'FunctionalPerl::Htmlgen::Mediawiki'=> [
        'Function::Parameters',
        'Encode',
-       'URI'
+       'URI',
    ],
    'FunctionalPerl::Htmlgen::MarkdownPlus'=> [
        'Function::Parameters',
@@ -80,13 +80,17 @@ our %dependencies=
    ],
    'FunctionalPerl::Htmlgen::Htmlparse'=> [
        'Function::Parameters',
-       'HTML::TreeBuilder'
+       'HTML::TreeBuilder',
    ],
    'Chj::HTTP::Daemon'=> [
-       'HTTP::Request'
+       'HTTP::Request',
    ],
-   map { $_ => [ 'Function::Parameters' ] }
-   qw(
+   'FunctionalPerl::Htmlgen::PerlTidy'=> [
+       'Function::Parameters',
+       'Perl::Tidy',
+   ],
+   (map { $_ => [ 'Function::Parameters' ] }
+    qw(
          FunctionalPerl::Htmlgen::Toc
          FunctionalPerl::Htmlgen::PXMLMapper
          FunctionalPerl::Htmlgen::FileUtil
@@ -94,10 +98,9 @@ our %dependencies=
          FunctionalPerl::Htmlgen::Cost
          FunctionalPerl::Htmlgen::Nav
          FunctionalPerl::Htmlgen::Sourcelang
-         FunctionalPerl::Htmlgen::PerlTidy
-   ),
-   map { $_ => ['FP::Repl::Dependencies'] }
-   qw(
+    )),
+   (map { $_ => ['FP::Repl::Dependencies'] }
+    qw(
          FP::Repl::Dependencies
          FP::Repl::Repl
          FP::Repl::StackPlus
@@ -105,7 +108,7 @@ our %dependencies=
          FP::Repl::WithRepl
          FP::Repl
          FP::Trie::t
-    ),
+    )),
   );
 
 
